aboutsummaryrefslogtreecommitdiff
path: root/object
diff options
context:
space:
mode:
Diffstat (limited to 'object')
-rw-r--r--object/signature/bytes.go (renamed from object/signature/serialize.go)4
1 files changed, 2 insertions, 2 deletions
diff --git a/object/signature/serialize.go b/object/signature/bytes.go
index 3f60d20d..0afff5e0 100644
--- a/object/signature/serialize.go
+++ b/object/signature/bytes.go
@@ -6,8 +6,8 @@ import (
"strings"
)
-// Serialize renders the signature in canonical Git format.
-func (signature Signature) Serialize() ([]byte, error) {
+// Bytes renders the signature in canonical Git format.
+func (signature Signature) Bytes() ([]byte, error) {
var b strings.Builder
b.Grow(len(signature.Name) + len(signature.Email) + 32)
b.Write(signature.Name)